<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>Expliquer</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Traduire</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>Demander à AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Résumé</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Cliquer sur l&apos;icône de la barre d&apos;état 
ou appuyer à nouveau sur le raccourci pour arrêter l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Ne faites pas pivoter votre écran pendant l&apos;enregistrement</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Enregistrement</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Fermer (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copier dans le presse-papiers (Entrée)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>L&apos;enregistrement a échoué. Veuillez l&apos;enregistrer dans votre répertoire personnel.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Capture d&apos;écran terminée</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>zone de sélection</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enregistré dans %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Presse-papiers</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Sauvegarde du fichier d&apos;enregistrement d&apos;écran, veuillez patienter...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Comme l&apos;effet de fenêtre a été désactivé pendant le processus, l&apos;enregistrement doit être arrêté</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Parchemin</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Captures d&apos;écran de l&apos;épingle</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Ouvrir un dossier</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Capture terminée et copiée dans le presse-papier</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Chaque demande</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Emplacement spécifié</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Définir un chemin d&apos;enregistrement</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Changer le chemin d&apos;enregistrement</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Captures d&apos;écran de l&apos;épingle</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Enregistrement</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Enregistrement terminé</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enregistré dans %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Ouvrir un dossier</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Chaque demande</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Emplacement spécifié</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Sélectionner un emplacement lors de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Mettre à jour l&apos;emplacement lors de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La capture d&apos;écran démarrera dans %1 secondes</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Obtenir de l&apos;aide.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Impossible de prendre une capture d&apos;écran continue.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Atteint le bas de la zone de défilement</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Atteint la longueur maximale</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ajuster la zone de capture</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Faire défiler la molette de votre souris ou cliquer pour prendre une capture d&apos;écran défilante</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Ralentir la vitesse de défilement</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Zone invalide, cliquer pour</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Saisir du texte ici</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Démarrer/Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Quitter/Enregistrer</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajustement de la taille</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Démarrage rapide</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Capture d&apos;écran de la fenêtre</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Délai de la capture d&apos;écran</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Capture d&apos;écran complète</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Augmenter la hauteur</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Augmenter la hauteur vers le bas</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Augmenter la largeur à gauche</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Augmenter la largeur à droite</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuer la hauteur</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuer la hauteur vers le bas</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuer la largeur à gauche</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuer la largeur à droite</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Frappe</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Caméra</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Démarrer l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Commencer l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Souris</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraire le texte</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Parchemin</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Épingler les captures d&apos;écran</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Démarrer l&apos;OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Démarrer en continue</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flèche</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rectangle
Maintenir la touche Maj enfoncée pour dessiner un carré</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Ellipse
Maintenir la touche Maj enfoncée pour dessiner un cercle</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Brosse
Maintenir la touche Maj enfoncée pour dessiner une ligne</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Ajuster l&apos;intensité du flou (utilisez la molette pour l&apos;ajuster)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Ajuster la taille de la brosse (utilisez la molette pour l&apos;ajuster)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Ajuster la texte du texte (utilisez la molette pour l&apos;ajuster)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Afficher la frappe (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Masquer la frappe (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Afficher la frappe (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Allumer la caméra (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Éteindre la caméra (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Paramètres (F3)</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microphone</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Système audio</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Afficher le pointeur</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Afficher les clics</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Enregistrer dans</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Ligne (L)
Maintenir la touche Maj enfoncée pour tracer une ligne verticale ou horizontale</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Flèche (X)
Maintenir la touche Maj enfoncée pour dessiner une flèche verticale ou horizontale</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Crayon (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Flou (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Texte (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Défilement (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Extraire le texte (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Captures d&apos;écran des épingles (Alt+P）</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Annuler (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Changer le chemin d&apos;enregistrement</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Effets de bordure</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Ombre</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Appareil</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extraire le texte</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Outils géométriques (R)
Maintenir la touche Maj enfoncée pour dessiner des carrés ou des cercles.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Enregistrer localement</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Enregistrer dans %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Emplacement spécifié</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Mettre à jour l&apos;emplacement lors de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Sélectionner un emplacement lors de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>Capture d&apos;écran AI (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Enregistrer sur le bureau</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Enregistrer dans les images</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Fermer (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copier dans le presse-papiers (Entrée)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajuster la zone d&apos;enregistrement dans %1*%2 pour obtenir un meilleur effet vidéo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>L&apos;enregistrement de l&apos;écran n&apos;est pas pris en charge actuellement</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
</TS>
